<?xml version="1.0"?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!-- inwarlpiri.xsl -->
<!-- This version redeveloped by Chris Manning for April 99 XSL draft -->
<!-- July 1999 -->
<!-- revised by Kristen August 2001 -->

<!-- inwarlpiri.xsl tries to print the glosses, if it can't find them,
     looks for paradigm glosses, if it can't find them, looks for definitions.
     It also prints the examples and the synonyms, same-as, and alternate
     forms. -->

<!-- order is ENTRY, HW, then link tags, text-only tags, and hidden tags, 
     and the rest alphabetically -->

<!-- note that link colors are now similar but not exactly matching to FunPanel -
     the idea was to enhance readability (darker colours) -->

<xsl:strip-space elements="*"/>

<xsl:output method="html" version="3.2"/>

<xsl:template match="/" xml:space="default">
<HTML>
<HEAD>
<TITLE>
<!-- I added this because it used to mess up the html by putting 
     all the headwords in the title. Maybe can do a check, to see 
     if there are < 5 or so? -KP -->
<xsl:text>Warlpiri Dictionary Word List</xsl:text>
</TITLE>
</HEAD>
<BODY BGCOLOR="white" LINK="blue" VLINK="red">
<xsl:if test="DICTIONARY/GLOSS">
Words that match<xsl:for-each select='DICTIONARY'>
	<B> <xsl:value-of select="GLOSS"/> </B> </xsl:for-each>:
            <xsl:for-each select='DICTIONARY/ENTRY'>	
		<xsl:if test="not(position()=last())">	                            
		<A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>,
		</xsl:if>
		<xsl:if test="(position()=last())">
			<xsl:if test="(position()=1)">
			<A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>.
			</xsl:if>
			<xsl:if test="not(position()=1)">
			and <A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>.
			</xsl:if>
		</xsl:if>
             </xsl:for-each>
</xsl:if>
<TABLE> <xsl:attribute name="WIDTH">100%</xsl:attribute>
	<xsl:attribute name="BORDER">0</xsl:attribute>
	<xsl:attribute name="CELLPADDING">0</xsl:attribute>
	<xsl:attribute name="CELLSPACING">0</xsl:attribute>
     <xsl:apply-templates select="DICTIONARY/ENTRY"/>
</TABLE>
</BODY>
</HTML>
</xsl:template>

<xsl:template match="ENTRY">
<TR><xsl:attribute name="VALIGN">top</xsl:attribute><TD>
<xsl:apply-templates select="HW" mode="title"/>
 <xsl:choose>
    <xsl:when test='EXAMPLES/EXAMPLE/WE/@TYPE'>
      <!-- Just suppress the other stuff if present -->
    </xsl:when>
    <xsl:when test='GL'>
      <xsl:apply-templates select='GL'/>
    </xsl:when>
    <xsl:when test='PDX/GL'>
      <xsl:apply-templates select='PDX'/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select='DEF'/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select='EXAMPLES'/>
  <xsl:if test='SYN|XME|ALT'>
    <DL><DT><FONT COLOR="#0000A0"><B>Yirdijarra jintangkajuku:</B></FONT></DT>
    <DD>
    <!-- We want to separate the different kinds by commas too... -->
    <xsl:apply-templates select='XME'/>
    <xsl:if test='XME and SYN'><xsl:text>, </xsl:text></xsl:if>
    <xsl:apply-templates select='SYN'/>
    <xsl:if test='ALT and (SYN or XME)'><xsl:text>, </xsl:text></xsl:if>
    <xsl:apply-templates select='ALT'/>
    </DD>
    </DL>
  </xsl:if>
  <xsl:text>
</xsl:text>
 <xsl:apply-templates select='SOUND'/>
</TD>
<xsl:for-each select="IMAGE">
     <TD><xsl:attribute name="ALIGN">right</xsl:attribute>
     <TABLE><xsl:attribute name="BORDER">0</xsl:attribute>
     <xsl:choose>
       <xsl:when test="count(IMGI) &gt; 3">
          <xsl:apply-templates mode='vertical'/>
       </xsl:when>
       <xsl:otherwise>
          <TR><xsl:apply-templates/></TR>
       </xsl:otherwise>
     </xsl:choose>
     </TABLE>
     </TD>
</xsl:for-each>
</TR>
</xsl:template>

<xsl:template match="HW" mode="title">
  <H1> <A><xsl:attribute name="NAME"><xsl:apply-templates select="."/></xsl:attribute>
<xsl:choose>
        <xsl:when test='@TYPE'>
          <I><xsl:apply-templates/></I>
        </xsl:when>
        <xsl:otherwise>
	   <xsl:apply-templates/>
        </xsl:otherwise>
    </xsl:choose>
    <xsl:if test='@HNUM'>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="@HNUM"/>
        <xsl:text>)</xsl:text>
    </xsl:if></A></H1>
</xsl:template>

<xsl:template match="HW">
	<xsl:apply-templates/>
</xsl:template>

<!-- link items -->
<xsl:template match="ALTI|XMEI|SYNI">
<xsl:text> </xsl:text>
<xsl:choose>
	<!-- USERFILE is a tag added in DictionaryCache.java when 
	     the user is saving a file to disk - then the links to 
	     other headwords no longer work, so don't make them. -->
	<xsl:when test="/DICTIONARY/DIR/USERFILE">
	<xsl:apply-templates/>
	</xsl:when>
	<xsl:otherwise>
	<xsl:choose>
   <xsl:when test='@HENTRY="?"'>
	<xsl:apply-templates/>
   </xsl:when>
   <xsl:otherwise>
     <xsl:choose>
        <xsl:when test='@HNUM="#"'>
        <!-- still can't resolve exactly: choice list would be good! -->
        <xsl:apply-templates/>
        </xsl:when>
        <xsl:when test='@HNUM'>
        <A>
        <xsl:attribute name="HREF">@<xsl:value-of 
        select="@HENTRY"/>@<xsl:value-of select="@HNUM"/>.html</xsl:attribute>
        <xsl:apply-templates/>
        </A>
        </xsl:when>
        <xsl:otherwise>
        <A>
        <xsl:attribute name="HREF">@<xsl:value-of 
                select="@HENTRY"/>@.html</xsl:attribute>
        <xsl:apply-templates/>
        </A>
        </xsl:otherwise>
     </xsl:choose>
   </xsl:otherwise>
</xsl:choose>
   </xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- Text-only items -->
<xsl:template match="EXAMPLES|SYN|ALT|XME">
  <xsl:apply-templates/>
</xsl:template>

<!-- items to hide -->
<xsl:template match="CM|CMP|DOMAIN|DMI|FREQ|LAT|REF|REFA|RUL|SRC|REM|USERFILE">
</xsl:template>

<!-- The rest of the tags, alphabetically -->

<xsl:template match="BF">
  <B><xsl:apply-templates/></B>
</xsl:template>

<xsl:template match="CT">
  <B><xsl:apply-templates/></B>
</xsl:template>

<xsl:template match="DEF|GL">
  <H2>
  <xsl:apply-templates/>
  </H2>
</xsl:template>

<!-- In basic, only print registers for main word -->
<xsl:template match="REGISTERS">
 <xsl:if test="../HW">
    <P><I><FONT SIZE="-1"><xsl:text>Registers: </xsl:text></FONT></I>
    <xsl:apply-templates/>
    </P>
 </xsl:if>
</xsl:template>

<xsl:template match="RGI">
     <xsl:choose>
     <xsl:when test=".='BT'">Baby Talk</xsl:when>
     <xsl:when test=".='SL'">Special Register Language</xsl:when>
     <xsl:otherwise><xsl:apply-templates/></xsl:otherwise>
     </xsl:choose>
</xsl:template>


<!-- Only show dialects for main words -->
<xsl:template match="DIALECTS">
 <xsl:if test="../HW">
    <P><I><FONT SIZE="-1"><xsl:text>Dialects: </xsl:text></FONT></I>
	<xsl:for-each select=".">
		<xsl:apply-templates/>
             <xsl:if test="not(position()=last())"><xsl:text>, </xsl:text></xsl:if>
        </xsl:for-each>
    </P>
 </xsl:if>
</xsl:template>

<!-- From the warlpiri website: DIALECT CODES ( )
(E) Eastern Warlpiri 
(H) Hansen River 
(La) Lajamanu 
(P) Papunya 
(Wi) Willowra (Wirliyajarrayi) 
(WW) Wakirti Warlpiri (Alekarange/ Tennant Creek) 
(Y) Yuendumu (Yurntumu) 
-->
<xsl:template match="DLI">
	<xsl:choose>
	<xsl:when test=".='Y'"><xsl:text>Yurntumu</xsl:text></xsl:when>
	<xsl:when test=".='H'"><xsl:text>Hansen River</xsl:text></xsl:when>
	<xsl:when test=".='La'"><xsl:text>Lajamanu</xsl:text></xsl:when>
	<xsl:when test=".='Wi'"><xsl:text>Wirliyajarrayi</xsl:text></xsl:when>
	<xsl:when test=".='E'"><xsl:text>Eastern Warlpiri</xsl:text></xsl:when>
	<xsl:when test=".='P'"><xsl:text>Papunya</xsl:text></xsl:when>
	<xsl:when test=".='WW'"><xsl:text>Wakirti Warlpiri</xsl:text></xsl:when>
	<xsl:otherwise><xsl:apply-templates/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="ET">
  <DD><FONT COLOR="#505050">
  <xsl:apply-templates/>
  </FONT></DD>
</xsl:template>

<xsl:template match="EXAMPLE">
  <xsl:apply-templates select='WE'/>
</xsl:template>

<!-- Now taken care of in ENTRY (couldn't figure out how to
     do it another way). -KP -->
<xsl:template match="IMAGE"> 
</xsl:template>

<xsl:template match="IMGI">
<!-- TR><xsl:attribute name="VALIGN">top</xsl:attribute -->
<TD><xsl:attribute name="ALIGN">right</xsl:attribute>
<FONT SIZE="-2">
<P ALIGN="right">
<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/> <xsl:apply-templates/>
</xsl:attribute>
<IMG><xsl:attribute name="SRC">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:attribute name="WIDTH">100</xsl:attribute>
<xsl:attribute name="HEIGHT">100</xsl:attribute>
</IMG></A>
  <!-- xsl:if test='@CREDITS'>
	<BR>
	<xsl:text>Image &#169; </xsl:text>
        <xsl:value-of select="@CREDITS"/>
	</BR>
    </xsl:if -->
</P></FONT>
</TD>
</xsl:template>

<xsl:template match="IMGI" mode='vertical'>
<TR><xsl:attribute name="VALIGN">top</xsl:attribute>
<TD><xsl:attribute name="ALIGN">right</xsl:attribute>
<P ALIGN="center">
<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/><xsl:apply-templates/>
</xsl:attribute>
<IMG><xsl:attribute name="SRC">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:attribute name="WIDTH">100</xsl:attribute>
<xsl:attribute name="HEIGHT">100</xsl:attribute>
</IMG></A>
</P>
</TD></TR>
</xsl:template>

<xsl:template match="IDIR|SDIR|DIR">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="LATIN">
  <FONT SIZE="-1"><I><xsl:apply-templates/></I></FONT>
</xsl:template>

<xsl:template match="PDX">
  <xsl:choose>
    <xsl:when test='GL'>
      <xsl:apply-templates select='GL'/>
    </xsl:when>
    <xsl:when test='DEF'>
      <xsl:apply-templates select='DEF'/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select='EXAMPLES'/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:if test='SYN|XME'>
    <DL><DT><FONT COLOR="#0000A0"><B>Yirdijarra jintangkajuku: </B></FONT></DT>
    <DD>
    <xsl:apply-templates select='XME'/>
    <xsl:apply-templates select='SYN'/>
    </DD>
    </DL>
  </xsl:if>
</xsl:template>
    
<xsl:template match="SOUND">
   <!-- only include sound if Audio is playable, which is coded as whether
   	the SDIR is put in the file -->
   <xsl:if test="/DICTIONARY/DIR/SDIR">
       <P><xsl:apply-templates/></P>
   </xsl:if>
</xsl:template>

<xsl:template match="SNDI">
	<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/SDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:text>Listen to this word!</xsl:text></A>
</xsl:template>

<xsl:template match="WE">
  <xsl:choose>
    <xsl:when test='@TYPE'>
      <H3>
      <xsl:apply-templates/>
      </H3>
    </xsl:when>
    <xsl:otherwise>
      <P><xsl:apply-templates/></P>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>

