<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<!-- meaning.xsl -->
<!-- This version redeveloped by Chris Manning for April 99 XSL draft -->
<!-- July 1999 -->
<!-- revised by Kristen August 2001 -->
<!-- Minor revisions Chris Nov 2001 -->

<!-- meaning.xsl displays the most relevant info it can find. First it looks
     for glosses, then if it can't find them, it looks for glosses in paradigms, 
     then a definition, then if it can't find anything, it looks for an example. 
     When it finds something, it prints it in large clear type. -->

<!-- order is ENTRY, HW, then link tags, text-only tags, and hidden tags, 
     and the rest alphabetically -->

<xsl:strip-space elements="*"/>

<xsl:output method="html" version="3.2"/>

<xsl:template match="/" xml:space="default">
<HTML>
<HEAD>
<TITLE>
<!-- I added this because it used to mess up the html by putting 
     all the headwords in the title. Maybe can do a check, to see 
     if there are < 5 or so? -KP -->
<xsl:text>Warlpiri Dictionary Word List</xsl:text>
</TITLE>
</HEAD>
<BODY BGCOLOR="white" LINK="blue" VLINK="red">
<xsl:if test="DICTIONARY/GLOSS">
Words that match<xsl:for-each select='DICTIONARY'>
	<B> <xsl:value-of select="GLOSS"/> </B> </xsl:for-each>:
            <xsl:for-each select='DICTIONARY/ENTRY'>	
		<xsl:if test="not(position()=last())">	                            
		<A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>,
		</xsl:if>
		<xsl:if test="(position()=last())">
			<xsl:if test="(position()=1)">
			<A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>.
			</xsl:if>
			<xsl:if test="not(position()=1)">
			and <A><xsl:attribute name="HREF">#<xsl:value-of select="HW"/></xsl:attribute><xsl:value-of select="HW"/></A>.
			</xsl:if>
		</xsl:if>
             </xsl:for-each>
</xsl:if>
<TABLE> <xsl:attribute name="WIDTH">100%</xsl:attribute>
	<xsl:attribute name="BORDER">0</xsl:attribute>
	<xsl:attribute name="CELLPADDING">0</xsl:attribute>
	<xsl:attribute name="CELLSPACING">0</xsl:attribute>
     <xsl:apply-templates select="DICTIONARY/ENTRY"/>
</TABLE>
</BODY>
</HTML>
</xsl:template>

<xsl:template match="ENTRY">
<TR><xsl:attribute name="VALIGN">top</xsl:attribute><TD>
<xsl:apply-templates select="HW" mode="title"/>
 <xsl:apply-templates select='SOUND'/>
   <xsl:choose>
    <xsl:when test='GL'>
      <xsl:apply-templates select='GL'/>
    </xsl:when>
    <xsl:when test='PDX/GL'>
      <xsl:apply-templates select='PDX'/>
    </xsl:when>
    <xsl:when test='DEF'>
      <xsl:apply-templates select='DEF'/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select='EXAMPLES'/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>
</xsl:text>
</TD>
<xsl:for-each select="IMAGE">
     <TD><xsl:attribute name="ALIGN">right</xsl:attribute>
     <TABLE><xsl:attribute name="BORDER">0</xsl:attribute>
     <xsl:choose>
       <xsl:when test="count(IMGI) &gt; 3">
          <xsl:apply-templates mode='vertical'/>
       </xsl:when>
       <xsl:otherwise>
          <TR><xsl:apply-templates/></TR>
       </xsl:otherwise>
     </xsl:choose>
     </TABLE>
     </TD>
</xsl:for-each>
</TR>
</xsl:template>

<xsl:template match="HW" mode="title">
  <H1> <A><xsl:attribute name="NAME"><xsl:apply-templates select="."/></xsl:attribute>
<xsl:choose>
        <xsl:when test='@TYPE'>
          <I><xsl:apply-templates/></I>
        </xsl:when>
        <xsl:otherwise>
	   <xsl:apply-templates/>
        </xsl:otherwise>
    </xsl:choose>
    <xsl:if test='@HNUM'>
        <xsl:text> (</xsl:text>
        <xsl:value-of select="@HNUM"/>
        <xsl:text>)</xsl:text>
    </xsl:if></A></H1>
</xsl:template>

<xsl:template match="HW">
   <xsl:apply-templates/>
</xsl:template>

<!-- link items -->
<xsl:template match="CTI">
<xsl:choose>
	<!-- USERFILE is a tag added in DictionaryCache.java when 
	     the user is saving a file to disk - then the links to 
	     other headwords no longer work, so don't make them. -->
	<xsl:when test="/DICTIONARY/DIR/USERFILE">
	<xsl:apply-templates/>
	</xsl:when>
	<xsl:otherwise>
	<xsl:choose>
   <xsl:when test='@HENTRY="?"'>
     <xsl:apply-templates/>
   </xsl:when>
   <xsl:otherwise>
     <xsl:choose>
        <xsl:when test='@HNUM="#"'>
        <!-- still can't resolve exactly: choice list would be good! -->
        <xsl:apply-templates/>
        </xsl:when>
        <xsl:when test='@HNUM'>
        <A>
        <xsl:attribute name="HREF">@<xsl:value-of 
        select="@HENTRY"/>@<xsl:value-of select="@HNUM"/>.html</xsl:attribute>
        <xsl:apply-templates/>
        </A>
        </xsl:when>
        <xsl:otherwise>
        <A>
        <xsl:attribute name="HREF">@<xsl:value-of 
                select="@HENTRY"/>@.html</xsl:attribute>
        <xsl:apply-templates/>
        </A>
        </xsl:otherwise>
     </xsl:choose>
   </xsl:otherwise>
</xsl:choose>
   </xsl:otherwise>
</xsl:choose>
</xsl:template>

<!-- Text-only items -->
<xsl:template match="GLI|EXAMPLE">
  <xsl:apply-templates/>
</xsl:template>

<!-- items to hide (among others) -->
<xsl:template match="CM|CMP|DOMAIN|DMI|FREQ|LAT|REF|REFA|RUL|SRC|USERFILE">
</xsl:template>

<!-- The rest of the tags, alphabetically -->
<xsl:template match="CT">
  <B><xsl:apply-templates/></B>
</xsl:template>

<xsl:template match="DEF|GL">
  <H2>
  <xsl:apply-templates/>
  </H2>
</xsl:template>

<xsl:template match="ET">
  <DD><FONT COLOR="#505050">
  <xsl:apply-templates/>
  </FONT></DD>
</xsl:template>

<xsl:template match="EXAMPLES">
  <FONT SIZE="+1">
  <DL>
  <xsl:apply-templates/>
  </DL>
  </FONT>
</xsl:template>

<!-- Now taken care of in ENTRY (couldn't figure out how to
     do it another way). -KP -->
<xsl:template match="IMAGE"> 
</xsl:template>

<xsl:template match="IMGI">
<TD><xsl:attribute name="ALIGN">right</xsl:attribute>
<P ALIGN="center">
<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/><xsl:apply-templates/>
</xsl:attribute>
<IMG><xsl:attribute name="SRC">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:attribute name="WIDTH">100</xsl:attribute>
<xsl:attribute name="HEIGHT">100</xsl:attribute>
</IMG></A>
</P>
</TD>
</xsl:template>

<xsl:template match="IMGI" mode='vertical'>
<TR><xsl:attribute name="VALIGN">top</xsl:attribute>
<TD><xsl:attribute name="ALIGN">right</xsl:attribute>
<P ALIGN="center">
<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/><xsl:apply-templates/>
</xsl:attribute>
<IMG><xsl:attribute name="SRC">
<xsl:apply-templates select="/DICTIONARY/DIR/IDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:attribute name="WIDTH">100</xsl:attribute>
<xsl:attribute name="HEIGHT">100</xsl:attribute>
</IMG></A>
</P>
</TD></TR>
</xsl:template>

<xsl:template match="IDIR|SDIR|DIR">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="LATIN">
  <I><xsl:apply-templates/></I>
</xsl:template>
    
<xsl:template match="PDX">
 <xsl:choose>
    <xsl:when test='GL'>
      <xsl:apply-templates select='GL'/>
    </xsl:when>
    <xsl:when test='DEF'>
      <xsl:apply-templates select='DEF'/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:apply-templates select='EXAMPLES'/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="SOUND">
   <!-- only include sound if Audio is playable, which is coded as whether
   	the SDIR is put in the file -->
   <xsl:if test="/DICTIONARY/DIR/SDIR">
       <P><xsl:apply-templates/></P>
   </xsl:if>
</xsl:template>

<xsl:template match="SNDI">
	<A><xsl:attribute name="HREF">
<xsl:apply-templates select="/DICTIONARY/DIR/SDIR"/>
	<xsl:apply-templates/></xsl:attribute>
<xsl:text>Listen to this word!</xsl:text></A>
</xsl:template>

<xsl:template match="WE">
<DT>
<xsl:choose>
   <xsl:when test='@TYPE'>
      <FONT COLOR="#400000">
      <xsl:apply-templates/>
      </FONT>
   </xsl:when>
   <xsl:otherwise>
      <xsl:apply-templates/>
   </xsl:otherwise>
</xsl:choose>
</DT>
</xsl:template>

</xsl:stylesheet>

